@@ -1,4 +1,4 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Dist/Zilla/PluginBundle/Author/VDB.pm
 #
@@ -17,7 +17,7 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Dist-Zilla-PluginBundle-Author-VDB. If not, see <http://www.gnu.org/licenses/>.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 
 #pod =head1 DESCRIPTION
 #pod
@@ -36,7 +36,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.11.2_03'; # TRIAL VERSION
+our $VERSION = 'v0.11.2_04'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -446,8 +446,9 @@ sub configure {
         ) : (
         ),
 
-        [ 'Manifest::Write' => { # REQUIRED VERSION: v0.9.0
+        [ 'Manifest::Write' => { # REQUIRED VERSION: v0.9.6
             # `Manifest::Write` v0.9.0 strictly requires plugin names, not monikers.
+            # `Manifest::Write` v0.9.6 provides `exclude_files` option.
             'source_provider' => [
                 "$name/Manifest::Read",
                 $self->copying ne '' ? "$name/COPYING" : (),
@@ -459,6 +460,9 @@ sub configure {
                 "$name/MetaJSON",
                 "$name/MetaYAML",
             ],
+            'exclude_files' => [
+                ":ExtraTestFiles",
+            ],
         } ],
 
         #
@@ -910,7 +914,13 @@ __PACKAGE__->meta->make_immutable();
 #pod
 #pod =cut
 
-# doc/what.pod #
+#   ------------------------------------------------------------------------------------------------
+#
+#   file: doc/what.pod
+#
+#   This file is part of perl-Dist-Zilla-PluginBundle-Author-VDB.
+#
+#   ------------------------------------------------------------------------------------------------
 
 #pod =encoding UTF-8
 #pod
@@ -921,7 +931,13 @@ __PACKAGE__->meta->make_immutable();
 #pod =cut
 
 # end of file #
-# doc/why.pod #
+#   ------------------------------------------------------------------------------------------------
+#
+#   doc/why.pod
+#
+#   This file is part of perl-Dist-Zilla-PluginBundle-Author-VDB.
+#
+#   ------------------------------------------------------------------------------------------------
 
 #pod =encoding UTF-8
 #pod
@@ -945,7 +961,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.11.2_03, released on 2016-11-25 22:29 UTC.
+Version v0.11.2_04, released on 2016-12-06 20:27 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
